PORT="<%= @tcp_port %>"
USER="<%= @user %>"
MAXCONN="<%= @max_connections %>"
<% Puppet::Parser::Functions.function('memcached_max_memory') -%>
CACHESIZE="<%= scope.function_memcached_max_memory([@max_memory]) %>"
OPTIONS="<%
result = []
if @verbosity
  result << '-' + @verbosity
end
if @lock_memory
  result << '-k'
end
if @listen_ip
  result << '-l ' + @listen_ip
end
if @udp_port
  result << '-U ' + @udp_port
end
if @item_size
  result << '-I ' + @item_size
end
result << '-t ' + @processorcount
-%><%= result.join(' ') -%>"
